<no title> — CALCEPH - C language 3.4.1 documentation

    int j;
    int res;
    double firsttime, lasttime;
    int itarget, iframe;
    t_calcephbin *peph;

    /* open the ephemeris file */
    peph = calceph_open("example1.dat");
    if (peph)
    {
       for (j=1; j<=calceph_getorientrecordcount(peph); j++)
       {
           calceph_getorientrecordindex(peph, j, &itarget, &firsttime, &lasttime, &iframe);
           printf("record %d : target=%d start=%23.16E end=%23.16E frame=%d\n",
                  j, itarget, firsttime, lasttime, iframe);
       }

       /* close the ephemeris file */
       calceph_close(peph);
    }